package com.ecarx.tip.base;

import android.app.Activity;
import android.app.Dialog;
import android.content.DialogInterface;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.support.annotation.CallSuper;
import android.support.annotation.DrawableRes;
import android.support.annotation.FloatRange;
import android.support.annotation.IntRange;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.annotation.StyleRes;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.FragmentActivity;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import com.ecarx.tip.R;
import com.ecarx.tip.XCTip;
import com.ecarx.tip.base.BaseDialog.BaseConfig;
import com.ecarx.tip.util.Utils;
import java.io.Serializable;
/* loaded from: classes.dex */
public abstract class BaseDialog<T extends BaseConfig> extends DialogFragment {
    public static final String CONFIG_KEY = "config_key";
    private static final String TAG = "BaseDialog";
    protected T mConfig;
    protected View mContentView;
    protected Dialog mDialog;
    protected Window mWindow;
    protected long startMillis;

    protected abstract void apply(T t);

    /* JADX INFO: Access modifiers changed from: protected */
    public abstract int bindLayout();

    protected abstract void initView();

    @Override // android.support.v4.app.DialogFragment, android.support.v4.app.Fragment
    public void onCreate(@Nullable Bundle bundle) {
        super.onCreate(bundle);
        if (bundle != null) {
            this.mConfig = (T) bundle.get(CONFIG_KEY);
        }
    }

    @Override // android.support.v4.app.DialogFragment
    @NonNull
    public Dialog onCreateDialog(Bundle bundle) {
        this.mDialog = new Dialog(getActivity(), this.mConfig.mThemeId);
        this.mWindow = this.mDialog.getWindow();
        setBaseView();
        initView();
        return this.mDialog;
    }

    @Override // android.support.v4.app.Fragment
    @Nullable
    public View onCreateView(LayoutInflater layoutInflater, @Nullable ViewGroup viewGroup, @Nullable Bundle bundle) {
        apply();
        return super.onCreateView(layoutInflater, viewGroup, bundle);
    }

    @Override // android.support.v4.app.Fragment
    public void onViewCreated(View view, @Nullable Bundle bundle) {
        Log.e(TAG, "onViewCreated: ");
        super.onViewCreated(view, bundle);
    }

    protected void setBaseView() {
        Dialog dialog = this.mDialog;
        View inflate = LayoutInflater.from(getActivity()).inflate(bindLayout(), (ViewGroup) null);
        this.mContentView = inflate;
        dialog.setContentView(inflate);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @CallSuper
    public void apply() {
        apply(this.mConfig);
        if (this.mConfig.widthScale != -1.0f) {
            this.mWindow.getAttributes().width = (int) (this.mConfig.widthScale * Utils.getScreenWidth());
        } else if (this.mConfig.width != -1) {
            this.mWindow.getAttributes().width = this.mConfig.width;
        }
        if (this.mConfig.heightScale != -1.0f) {
            this.mWindow.getAttributes().height = (int) (this.mConfig.heightScale * Utils.getScreenHeight());
        } else if (this.mConfig.height != -1) {
            this.mWindow.getAttributes().height = this.mConfig.height;
        }
        if (this.mConfig.gravity != -1) {
            this.mWindow.setGravity(this.mConfig.gravity);
        }
        if (this.mConfig.alpha != -1.0f) {
            this.mWindow.getAttributes().alpha = this.mConfig.alpha;
        }
        if (this.mConfig.drawable != null) {
            this.mWindow.setBackgroundDrawable(this.mConfig.drawable);
        }
        if (this.mConfig.resId != -1) {
            this.mWindow.setBackgroundDrawableResource(this.mConfig.resId);
        }
        if (!this.mConfig.cancelable) {
            setCancelable(false);
        }
        if (!this.mConfig.cancelOnTouchOutside) {
            this.mDialog.setCanceledOnTouchOutside(false);
        }
        if (this.mConfig.onShowListener != null) {
            this.mDialog.setOnShowListener(this.mConfig.onShowListener);
        }
    }

    @Override // android.support.v4.app.DialogFragment, android.content.DialogInterface.OnCancelListener
    public void onCancel(DialogInterface dialogInterface) {
        if (this.mConfig.onCancelListener != null) {
            this.mConfig.onCancelListener.onCancel(dialogInterface);
        }
        super.onCancel(dialogInterface);
    }

    public void show() {
        Activity topActivity = XCTip.getTopActivity();
        if (topActivity == null) {
            throw new NullPointerException("top activity is null");
        }
        if (!(topActivity instanceof FragmentActivity)) {
            throw new IllegalArgumentException("ur activity should instanceof FragmentActivity");
        }
        show((FragmentActivity) topActivity);
    }

    public void show(FragmentActivity fragmentActivity) {
        if (System.currentTimeMillis() - this.startMillis >= 200 && !isAdded()) {
            if (this.mConfig == null) {
                this.mConfig = (T) getArguments().getSerializable(CONFIG_KEY);
            }
            if (this.mConfig == null) {
                throw new NullPointerException("config is null");
            }
            super.show(fragmentActivity.getSupportFragmentManager(), this.mConfig.getClass().getName());
            this.startMillis = System.currentTimeMillis();
            Utils.logW("belongs to " + XCTip.getApp().getPackageName());
        }
    }

    public <V extends View> V findViewById(int i) {
        return (V) this.mContentView.findViewById(i);
    }

    /* loaded from: classes.dex */
    public class BaseConfig<T extends BaseConfig> implements Serializable {
        float alpha;
        boolean cancelOnTouchOutside;
        boolean cancelable;
        transient Drawable drawable;
        int gravity;
        int height;
        float heightScale;
        int mThemeId;
        transient DialogInterface.OnCancelListener onCancelListener;
        transient DialogInterface.OnShowListener onShowListener;
        int resId;
        int width;
        float widthScale;

        public BaseConfig() {
            this(R.style.BaseDialogTheme);
        }

        public BaseConfig(@StyleRes int i) {
            this.widthScale = -1.0f;
            this.heightScale = -1.0f;
            this.width = -1;
            this.height = -1;
            this.gravity = -1;
            this.alpha = -1.0f;
            this.resId = -1;
            this.cancelable = true;
            this.cancelOnTouchOutside = true;
            this.mThemeId = i;
        }

        public T setSize(@FloatRange(from = 0.0d, fromInclusive = false, to = 1.0d) float f, @FloatRange(from = 0.0d, fromInclusive = false, to = 1.0d) float f2) {
            this.widthScale = f;
            this.heightScale = f2;
            return this;
        }

        public T setWidth(@FloatRange(from = 0.0d, fromInclusive = false, to = 1.0d) float f) {
            this.widthScale = f;
            return this;
        }

        public T setHeight(@FloatRange(from = 0.0d, fromInclusive = false, to = 1.0d) float f) {
            this.heightScale = f;
            return this;
        }

        public T setWidth(@IntRange(from = 8) int i) {
            this.width = i;
            return this;
        }

        public T setHeight(@IntRange(from = 8) int i) {
            this.height = i;
            return this;
        }

        public T setGravity(int i) {
            this.gravity = i;
            return this;
        }

        public T setAlpha(@FloatRange(from = 0.0d, fromInclusive = false, to = 1.0d) float f) {
            this.alpha = f;
            return this;
        }

        public T setBg(Drawable drawable) {
            this.drawable = drawable;
            return this;
        }

        public T setBgRes(@DrawableRes int i) {
            this.resId = i;
            return this;
        }

        public T setCanceled(boolean z) {
            this.cancelable = z;
            return this;
        }

        public T setCanceledOnTouchOutside(boolean z) {
            this.cancelOnTouchOutside = z;
            return this;
        }

        public T setOnCancelListener(DialogInterface.OnCancelListener onCancelListener) {
            this.onCancelListener = onCancelListener;
            return this;
        }

        public T setOnShowListener(DialogInterface.OnShowListener onShowListener) {
            this.onShowListener = onShowListener;
            return this;
        }
    }

    @Override // android.support.v4.app.DialogFragment, android.support.v4.app.Fragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        bundle.putSerializable(CONFIG_KEY, this.mConfig);
    }

    @Override // android.support.v4.app.DialogFragment
    public void dismiss() {
        super.dismissAllowingStateLoss();
    }
}
